@@ -5,6 +5,7 @@ from typing import Callable
 from typing import Optional
 from types import ModuleType
 
+import os
 import json
 import yaml
 
@@ -20,22 +21,39 @@ class UnknownTypeException(Exception):
 
 
 class SyncConfig:
-    def __init__(self, name: str, sync_type: str, path: str):
+    def __init__(self, name: str, path: str, sync_type: str = "auto") -> None:
         '''
         Parameters
         ----------
             name: str
                 Name of the attribute alias
+            path: str
+                Path to file in the repository
             sync_type : str
                 File type. Available options are :code:`"text"` (plain text file, will be converted
                 to python string), :code:`"json"`, :code:`"yaml"` (converted to python dict)
-                and :code:`"module"` (will be imported the file as python module)
-            path: str
-                Path to file in the repository
+                and :code:`"module"` (will be imported the file as python module). :code:`"auto"` to
+                automatically detect sync type from file extension
+
         '''
         self.name = name
-        self.type = sync_type
         self.file_path = path
+        self.type = sync_type
+
+        if sync_type == "auto":
+            self.__get_auto_type()
+
+    def __get_auto_type(self) -> None:
+        file_ext = os.path.splitext(self.file_path)[-1]
+
+        if file_ext in [".yaml", ".yml"]:
+            self.type = "yaml"
+        elif file_ext == ".json":
+            self.type = "json"
+        elif file_ext == ".py":
+            self.type = "module"
+        else:
+            self.type = "text"
 
 
 class Repo:
@@ -54,8 +72,9 @@ class Repo:
         self.__commit_hash = ""
         self.__values: ThreadSafeDict = ThreadSafeDict()
         self.__config: List[SyncConfig]
-        self.__update_callback: Optional[Callable[[Any], None]] = None
-        self.__thread_loop = ThreadLoop(SYNCGIT_DEFAULT_POLL_INTERVAL, self.__update)
+        self.__update_callback: Optional[Callable[[Any, List[SyncConfig]], None]] = None
+        self.__thread_loop = ThreadLoop(
+            SYNCGIT_DEFAULT_POLL_INTERVAL, self.__update)
 
     @property
     def commit_hash(self) -> str:
@@ -75,16 +94,17 @@ class Repo:
         '''
         self.__thread_loop.set_interval(seconds)
 
-    def set_update_callback(self, callback: Callable[[Any], None]) -> None:
+    def set_update_callback(self, callback: Callable[[Any, List[SyncConfig]], None]) -> None:
         '''
         Set callback to be call after synchronization is complete
 
         Parameters
         ----------
-        callback : Callable[[Repo], None]
+        callback : Callable[[Repo, List[SyncConfig]], None]
             This callback will be called when changes are pushed to the repo and
-            the new changes have been synchronized. The callback should accept one
-            argument, the Repo class
+            the new changes have been synchronized. The callback should accept two
+            arguments, the Repo class and List[SyncConfig], config attributes which
+            got updated
         '''
         self.__update_callback = callback
 
@@ -126,13 +146,15 @@ class Repo:
         if not self.__pull():
             return
 
-        files = self.__get_files()
+        changed_configs = self.__get_changed_configs()
 
-        for config in self.__config:
+        files = self.__get_files(changed_configs)
+
+        for config in changed_configs:
             self.__set_value(config, files[config.file_path])
 
         if self.__update_callback is not None:
-            self.__update_callback(self)
+            self.__update_callback(self, changed_configs)
 
     def __set_value(self, config: SyncConfig, str_value: str) -> None:
         if config.type == "text":
@@ -152,15 +174,27 @@ class Repo:
         exec(compiled, module.__dict__)  # pylint: disable=exec-used
         self.__values[name] = module
 
-    def __get_files(self) -> Dict[str, str]:
-        files: Dict[str, str] = {}
+    def __get_changed_configs(self) -> List[SyncConfig]:
+        changes = gitcmd.changes(self.__repo_info)
+        first_update = len(self.__values) == 0
+        changed_configs = []
 
         for config in self.__config:
-            file_path = config.file_path
-            file_path_absolute = self.__repo_info.get_abs_path(file_path)
+            if config.file_path not in changes and not first_update:
+                continue
+
+            changed_configs.append(config)
+
+        return changed_configs
+
+    def __get_files(self, configs: List[SyncConfig]) -> Dict[str, str]:
+        files: Dict[str, str] = {}
+
+        for config in configs:
+            file_path_absolute = self.__repo_info.get_abs_path(config.file_path)
 
             with open(file_path_absolute) as file:
-                files[file_path] = file.read()
+                files[config.file_path] = file.read()
 
         return files
 
